# Roadmap

Features that have or might be implemented in the `okcourse` library project.

- [x] Implemented
- [ ] Not implemented
___

- [ ] Library
    - [x] Generate course outline
    - [x] Generate course lectures from outline
    - [x] Generate course cover art (PNG)
    - [x] Generate course audio (MP3) from lectures
    - [x] No dependency on `FFmpeg`
    - [ ] No dependency on `nltk`
    - [ ] Report generator progress
    - [ ] Anthropic-based generator
    - [ ] Generate speech with locally hosted TTS model
    - [ ] Full unit test coverage
- [ ] Docs
    - [x] README
    - [x] CONTRIBUTE
    - [x] LICENSE
    - [x] okcourse documentation on GitHub Pages
    - [ ] API reference: all public members fully documented (including example snippets)
    - [ ] Guide: *Get started* (multi-part; not just the `README`)
    - [ ] How-to: Determine and estimate cost
    - [ ] How-to: Create a custom course type
    - [ ] Reference: Release notes (automated)
- [ ] Example apps and courses
    - [x] CLI - async
    - [x] Streamlit
    - [ ] CLI - sync
    - [ ] Course MP3 examples (download and/or stream)
- [ ] Package dist / Infrastructure
    - [x] Publish `okcourse` package on PyPi
    - [ ] Automated build + release pipeline
    - [ ] Automated tests